@@ -19,7 +19,7 @@ main = xlab = ylab = function(graph, label=NULL){
 
 update.scatterplot = update.tsplot = update.fittedlineplot = UpdateGraph = function(object, ...){
       MC <- match.call(expand.dots = TRUE)
-      ParSet = as.list(MC[-c(1,2)])
+      ParSet = (as.list(MC))[-c(1,2)]
       Obj = as.character(match.call()[["object"]])
       Out = object
 # now sift ExtraArgs from ParSet and update them
